@@ -16,7 +16,7 @@ const char *config_maildropfilter()
 {
 	if (!maildrop)
 	{
-	char	*filename=config_search("maildropfilter");
+	char	*filename=config_localfilename("maildropfilter");
 
 		maildrop=config_read1l(filename);
 		free(filename);
