@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2012 Double Precision, Inc.
+** Copyright 1998 - 2018 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -32,6 +32,7 @@
 #include	"comsubmitclient.h"
 #include	"comreadtime.h"
 #include	"rfc822/rfc822.h"
+#include	"rfc2045/rfc2045.h"
 #include	"waitlib/waitlib.h"
 #include	"esmtpiov.h"
 #include	"esmtpconfig.h"
@@ -162,15 +163,19 @@ EHLO_EXDATA_EXTENSION
 EHLO_SECURITY_EXTENSION
 "250-PIPELINING\r\n"
 "250-8BITMIME\r\n"
+"250-SMTPUTF8\r\n"
 "250-SIZE\r\n"
 "250 DSN\r\n";
-const char *me=config_me();
+const char *me=config_me_ace();
 const char *p, *q;
 
-	if (helobuf[0] == 0) 
+	if (helobuf[0] == 0)
 	{
 		char *p;
 
+		while (*heloname == ' ')
+		       ++heloname;
+
 		strncat(helobuf, heloname, sizeof(helobuf)-1);
 
 		for (p=helobuf; *p; p++)
@@ -258,7 +263,7 @@ int	rc;
 	a=rfc822a_alloc(t);
 	if (!a)	clog_msg_errno();
 
-	if (a->naddrs != 1 || a->addrs[0].tokens == 0)
+	if (a->naddrs < 1 || a->addrs[0].tokens == 0)
 	{
 		addiovec_error("502 EXPN syntax error.");
 		rfc822a_free(a);
@@ -536,12 +541,13 @@ const char *q=skipaddress(&p);
 
 static int domailfrom(const char *p, const char *q)
 {
-const char *r, *s;
-char	retformat=0;
-const char *envid=0;
-size_t	envidlen=0;
-char	*buf;
-int	rc;
+	const char *r, *s;
+	char	retformat=0;
+	const char *envid=0;
+	size_t	envidlen=0;
+	char	*buf;
+	int	rc;
+	int	smtputf8=0;
 
 	hasexdata=0;
 	hasverp=0;
@@ -634,6 +640,19 @@ int	rc;
 				l=n;
 			}
 		}
+		else if (s - r >= 8 &&
+#if HAVE_STRNCASECMP
+			 strncasecmp(r, "SMTPUTF8", 8)
+#else
+			 strnicmp(r, "SMTPUTF8", 8)
+#endif
+			 == 0)
+		{
+			if (s-r == 8 || r[8] == '=')
+			{
+				smtputf8=1;
+			}
+		}
 		r= s-1;
 	}
 
@@ -656,6 +675,10 @@ int	rc;
 	{
 		strcat(buf, "S{STARTTLS}");
 	}
+	if (smtputf8)
+	{
+		strcat(buf, "8");
+	}
 
 	if (envidlen)
 	{
@@ -753,8 +776,8 @@ static int rcpttolocal(const char *p, const char *r, const char *q)
 static int dorcptto2(const char *p, const char *q)
 {
 int	notifyn=0,notifyf=0,notifys=0,notifyd=0;
-const char *orcpt=0;
-int	orcptlen=0;
+char	*orcpt_utf8=0;
+size_t  orcpt_utf8_len=0;
 const char *r, *s;
 char	*t, *buf;
 const char *relayclient=getenv("RELAYCLIENT");
@@ -806,13 +829,24 @@ int	rc;
 #endif
 			== 0)
 		{
+			char *encoded_orcpt;
+
 			r += 6;
-			orcpt=r;
-			orcptlen=s-r;
+
+			encoded_orcpt=malloc(s-r+1);
+			if (!encoded_orcpt)
+				abort();
+			memcpy(encoded_orcpt, r, s-r);
+			encoded_orcpt[s-r]=0;
+			orcpt_utf8=rfc6533_decode(encoded_orcpt);
+			free(encoded_orcpt);
 		}
 	}
 
-	buf=courier_malloc(q-p + relayclientl + orcptlen + 10);
+	if (orcpt_utf8)
+		orcpt_utf8_len=strlen(orcpt_utf8);
+
+	buf=courier_malloc(q-p + relayclientl + orcpt_utf8_len + 10);
 	memcpy(buf, p, q-p);
 	t=buf + (q-p);
 	if (relayclientl)
@@ -832,9 +866,12 @@ int	rc;
 			*t++ = 'D';
 	}
 	*t++ = '\t';
-	if (orcptlen)
-		memcpy(t, orcpt, orcptlen);
-	t[orcptlen]=0;
+
+	if (orcpt_utf8_len)
+		memcpy(t, orcpt_utf8, orcpt_utf8_len);
+	t[orcpt_utf8_len]=0;
+	if (orcpt_utf8)
+		free(orcpt_utf8);
 
 	submit_write_message(buf);
 	free(buf);
@@ -1063,7 +1100,12 @@ int	authenticated=0;
 		if (p && *p && config_has_vhost(p))
 			config_set_local_vhost(p);
 
-		clog_open_syslog("courieresmtpd");
+		p=getenv("SYSLOGNAME");
+
+		if (!p || !*p)
+			p="courieresmtpd";
+
+		clog_open_syslog(p);
 
 		if ((p=getenv("ESMTP_TLS")) && atoi(p))
 		{
@@ -1385,6 +1427,13 @@ int	authenticated=0;
 			continue;
 		}
 
+		if (strncmp(line, "NOOP", 4) == 0)
+		{
+			addiovec("250 Ok\r\n", 8);
+			iovflush();
+			continue;
+		}
+
 		if (auth_required && !authenticated && strcmp(line, "RSET"))
 		{
 			addiovec_error("535 Authentication required.");
@@ -1428,12 +1477,6 @@ int	authenticated=0;
 			set_submit_error(0, 0);
 			continue;
 		}
-		if (strncmp(line, "NOOP", 4) == 0)
-		{
-			addiovec("250 Ok\r\n", 8);
-			iovflush();
-			continue;
-		}
 		if (strncmp(line, "MAIL", 4) == 0 && (p=strchr(line, ':')) != 0
 			&& !seenmailfrom)
 		{
