@@ -1,10 +1,8 @@
-#! perl
 #
 # TITLE: MySQL
 #
-# $Id: admin-15mysql.pl,v 1.5 2003/06/17 15:44:34 mrsam Exp $
 #
-# Copyright 2001 Double Precision, Inc.  See COPYING for
+# Copyright 2001-2004 Double Precision, Inc.  See COPYING for
 # distribution information.
 
 use webadmin;
@@ -12,8 +10,7 @@ use webadmin;
 my $errstr="";
 
 display_form("notsupp.html")
-    unless -f "$libexecdir/authlib/authmysql" ||
-    -f "$libexecdir/authlib/authdaemond.mysql";
+    unless -f "$authmysqlrc";
 
 if ($cgi->param("Save"))
 {
@@ -60,7 +57,7 @@ if ($cgi->param("Save"))
     {
 	$errstr="\@SAVED\@";
     }
-    changed("test ! -x $libexecdir/authlib/authdaemond || $libexecdir/authlib/authdaemond restart");
+    changed("$authdaemond restart");
 }
 
 my $mysql=ReadKWConfigFile("authmysqlrc");
