@@ -1,10 +1,8 @@
-#! perl
 #
 # TITLE: PostgreSQL
 #
-# $Id: admin-15pgsql.pl,v 1.2 2003/06/17 15:44:34 mrsam Exp $
 #
-# Copyright 2001 Double Precision, Inc.  See COPYING for
+# Copyright 2001-2004 Double Precision, Inc.  See COPYING for
 # distribution information.
 
 use webadmin;
@@ -12,8 +10,7 @@ use webadmin;
 my $errstr="";
 
 display_form("notsupp.html")
-    unless -f "$libexecdir/authlib/authpgsql" ||
-    -f "$libexecdir/authlib/authdaemond.pgsql";
+    unless -f "$authpgsqlrc";
 
 if ($cgi->param("Save"))
 {
@@ -58,7 +55,7 @@ if ($cgi->param("Save"))
     {
 	$errstr="\@SAVED\@";
     }
-    changed("test ! -x $libexecdir/authlib/authdaemond || $libexecdir/authlib/authdaemond restart");
+    changed("$authdaemond restart");
 }
 
 my $pgsql=ReadKWConfigFile("authpgsqlrc");
