@@ -68,7 +68,7 @@
 #endif
 #include	<errno.h>
 
-#include	"unicode/unicode.h"
+#include	<courier-unicode.h>
 
 #include	<unistd.h>
 #if HAVE_WCHAR_H
@@ -156,7 +156,7 @@ void call_print_safe_to_stdout(const char *p, size_t cnt)
 {
 	print_safe_len(p, cnt, print_safe_to_stdout);
 }
-	
+
 void folder_contents_title()
 {
 const char *lab;
@@ -190,10 +190,10 @@ int in_utf8;
 		printf("%s", lab);
 
 		origff=ff=in_utf8 ?
-			libmail_u_convert_fromutf8(f,
+			unicode_convert_fromutf8(f,
 						   sqwebmail_content_charset,
 						   NULL)
-			: folder_fromutf7(f);
+			: folder_fromutf8(f);
 
 		if (strcmp(ff, NEWSHAREDSP) == 0 ||
 		    strncmp(ff, NEWSHAREDSP ".", sizeof(NEWSHAREDSP)) == 0)
@@ -285,13 +285,13 @@ static const char *do_folder_delmsgs(const char *dir, size_t pos)
 	{
 		rc=group_movedel( dir, &groupdel );
 		maildir_savefoldermsgs(dir);
-	} 
-	else if (*cgi("cmdpurgeall")) 
+	}
+	else if (*cgi("cmdpurgeall"))
 	{
 	    char *deldir;
 	    struct maildir_info minfo;
 
-	    if (maildir_info_imap_find(&minfo, dir, login_returnaddr())<0) 
+	    if (maildir_info_imap_find(&minfo, dir, login_returnaddr())<0)
 		    return "othererror";
 
 	    if ((deldir=maildir_name2dir(minfo.homedir, minfo.maildir)) == NULL)
@@ -299,7 +299,7 @@ static const char *do_folder_delmsgs(const char *dir, size_t pos)
 		maildir_info_destroy(&minfo);
 		return "othererror";
 	    }
-	    
+
 	    cur = malloc(strlen(deldir)+5);
 	    strcpy(cur, deldir);
 	    strcat(cur, "/cur");
@@ -310,7 +310,7 @@ static const char *do_folder_delmsgs(const char *dir, size_t pos)
 	    maildir_info_destroy(&minfo);
 	    free(deldir);
 	    free(cur);
-	    
+
 	}
 	else if (*cgi("cmdmove"))
 	{
@@ -334,7 +334,7 @@ static const char *do_folder_delmsgs(const char *dir, size_t pos)
 void folder_delmsgs(const char *dir, size_t pos)
 {
 	const char *status=do_folder_delmsgs(dir, pos);
-	
+
 	if (*cgi("search"))
 		http_redirect_argsss("&error=%s&form=folder&pos=%s&search=1&"
 				     SEARCHRESFILENAME "=%s", status,
@@ -721,7 +721,7 @@ static void show_msg_match_str(const char *prefix,
 {
 	char *p;
 
-	p=libmail_u_convert_fromutf8(utf8match, sqwebmail_content_charset,
+	p=unicode_convert_fromutf8(utf8match, sqwebmail_content_charset,
 				     NULL);
 
 	if (p)
@@ -1322,7 +1322,7 @@ void folder_nextprev()
 
 void list_folder(const char *p)
 {
-	char *s=folder_fromutf7(p);
+	char *s=folder_fromutf8(p);
 	print_safe(s);
 	free(s);
 }
@@ -1358,7 +1358,7 @@ static void show_transfer_dest_real(const char *, const char *,
 				    const char *, const char *);
 static void show_transfer_dest_fake(const char *,
 				    struct maildir_shindex_cache *);
-			    
+
 static void show_transfer_dest(const char *cur_folder)
 {
 	parse_hierarchy(cur_folder, show_transfer_dest_real,
@@ -2630,8 +2630,8 @@ void folder_list()
 		if (!*folderdir)
 			folderdir=INBOX;
 
-		futf7=folder_toutf7(newfoldername);
-		dutf7=folder_toutf7(newdirname);;
+		futf7=folder_toutf8(newfoldername);
+		dutf7=folder_toutf8(newdirname);;
 
 		if (!*newfoldername ||
 		    strchr(futf7, '.') ||
@@ -2755,7 +2755,7 @@ void folder_list()
 		char	*s;
 		char	*rutf7;
 
-		rutf7=folder_toutf7(r);
+		rutf7=folder_toutf8(r);
 
 		s=malloc(strlen(qutf7)+strlen(rutf7)+1);
 
@@ -2830,7 +2830,7 @@ static void parse_hierarchy(const char *folderdir,
 
 	if (strchr(folderdir, '/'))
 		enomem();
-		
+
 	if (strncmp(folderdir, NEWSHAREDSP, sizeof(NEWSHAREDSP)-1) == 0)
 		switch (folderdir[sizeof(NEWSHAREDSP)-1]) {
 		case 0:
@@ -3643,7 +3643,7 @@ void folder_showtransfer()
 	}
 
 	if ((strcmp(sqwebmail_folder, INBOX "." TRASH) == 0) && (strlen(getarg("PURGEALL"))))
-	    printf("<input type=\"submit\" name=\"cmdpurgeall\" value=\"%s\" onclick=\"javascript: return deleteAll();\" />", 
+	    printf("<input type=\"submit\" name=\"cmdpurgeall\" value=\"%s\" onclick=\"javascript: return deleteAll();\" />",
 		getarg("PURGEALL"));
 	printf("<input type=\"submit\" name=\"cmddel\" value=\"%s\" />%s<select name=\"moveto\">",
 		strcmp(sqwebmail_folder, INBOX "." TRASH) == 0
@@ -3715,22 +3715,22 @@ static char *truncate_at(const char *str,
 			 const char *charset,
 			 size_t ncols)
 {
-	unicode_char *uc;
+	char32_t *uc;
 	size_t n;
 	size_t cols, tp=0;
 	char *retbuf;
-	libmail_u_convert_handle_t h;
+	unicode_convert_handle_t h;
 	int chopped=0;
 
 	if (!str)
 		return NULL;
 
-	h=libmail_u_convert_tou_init("utf-8", &uc, &n, 1);
+	h=unicode_convert_tou_init("utf-8", &uc, &n, 1);
 
 	if (h)
 	{
-		libmail_u_convert(h, str, strlen(str));
-		libmail_u_convert_deinit(h, NULL);
+		unicode_convert(h, str, strlen(str));
+		unicode_convert_deinit(h, NULL);
 	}
 	else
 	{
@@ -3756,7 +3756,7 @@ static char *truncate_at(const char *str,
 
 	if (chopped)
 	{
-		uc = realloc(uc, sizeof(unicode_char) * (tp+4));
+		uc = realloc(uc, sizeof(char32_t) * (tp+4));
 		if (uc == 0) enomem();
 		uc[tp]='.';
 		uc[tp+1]='.';
@@ -3764,12 +3764,12 @@ static char *truncate_at(const char *str,
 		tp += 3;
 	}
 
-	h=libmail_u_convert_fromu_init(charset, &retbuf, &cols, 1);
+	h=unicode_convert_fromu_init(charset, &retbuf, &cols, 1);
 
 	if (h)
 	{
-		libmail_u_convert_uc(h, uc, tp);
-		libmail_u_convert_deinit(h, NULL);
+		unicode_convert_uc(h, uc, tp);
+		unicode_convert_deinit(h, NULL);
 	}
 	else
 	{
